local gtt = GameTooltip;

-- Variables
local ttm = CreateFrame("Frame","TipTacMSP");
local current = {};

-- Allow these to be accessed externally from other addons
ttm.current = current;

ttm:Hide();

--------------------------------------------------------------------------------------------------------
--                                           Gather MSP
--------------------------------------------------------------------------------------------------------

local function GatherMSP(field)
	if _G.msp ~= nil then
		playername = current.name;
		_G.msp.Request(playername, field);
		if (_G.msp.char[playername] ~= nil) then
			if (_G.msp.char[playername].field[field] ~= "") then
				return _G.msp.char[playername].field[field]
			end
		end
		return nil
	else
		return "No MSP-Compatible Addon found"
	end
end

function TipTacMSPFindConfigWindowAndAddOwnConfig()
	-- "Workaround" to add the Options to the TipTac-Options-Menu
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPName", label = "Show MSP Name", tip = "Shows the MSP Name in the Game Tooltip."};
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPState", label = "Show MSP Status", tip = "Shows the MSP Status in the Game Tooltip."};
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPStyle", label = "Show MSP RP Style", tip = "Shows the MSP Roleplay Style in the Game Tooltip."};
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPClient", label = "Show MSP Client", tip = "Shows the MSP Client(s) in the Game Tooltip."};
	
	-- Set Defaults in this "Workaround"
	if (TipTac_Config.showMSPState == nil) then
		print("TipTacMSP-Status Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config.showMSPState = true;
	end
	if (TipTac_Config.showMSPName == nil) then
		print("TipTacMSP-Name Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config.showMSPName = true;
	end
	if (TipTac_Config.showMSPClient == nil) then
		print("TipTacMSP-Client Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config.showMSPClient = false;
	end
	if (TipTac_Config.showMSPStyle == nil) then
		print("TipTacMSP-RP-Style Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config.showMSPStyle = false;
	end
end

gtt:HookScript("OnTooltipSetUnit",function(self,...)
	-- Get the unit -- Check the UnitFrame unit if this tip is from a concated unit, such as "targettarget".
	local _, unit = self:GetUnit();
	if (not unit) then
		local mFocus = GetMouseFocus();
		if (mFocus) and (mFocus.unit) then
			unit = mFocus.unit;
		end
	end
	
	-- No Unit or not a Player
	if (not unit) or (not UnitIsPlayer(unit)) then
		return;
	end
	
	-- Wipe Current Record
	wipe(current);
	current.unit = unit;
	current.name = UnitName(unit);
	current.guid = UnitGUID(unit);
	
	if (TipTac_Config.showMSPName) then
		current.msp_na = GatherMSP("NA");
		if ((current.msp_na ~= nil) and (current.msp_na ~= current.name)) then
			self:AddLine("MSP-Name: "..current.msp_na);
		end
	end
	if (TipTac_Config.showMSPState) then
		current.msp_fc = GatherMSP("FC");
		if (current.msp_fc ~= nil) then
			if (current.msp_fc == "0") then
				self:AddLine("MSP-Status: undefined");
			elseif (current.msp_fc == "1") then
				self:AddLine("MSP-Status: OOC");
			elseif (current.msp_fc == "2") then
				self:AddLine("MSP-Status: IC");
			elseif (current.msp_fc == "3") then
				self:AddLine("MSP-Status: Looking For Contact");
			elseif (current.msp_fc == "4") then
				self:AddLine("MSP-Status: Storyteller");
			else
				self:AddLine("MSP-Status: "..current.msp_fc);
			end
			
		end
	end
	if (TipTac_Config.showMSPStyle) then
		current.msp_fr = GatherMSP("FR");
		if (current.msp_fr ~= nil) then
			if (current.msp_fr == "0") then
				self:AddLine("MSP-Style: undefined");
			elseif (current.msp_fr == "1") then
				self:AddLine("MSP-Style: Normal");
			elseif (current.msp_fr == "2") then
				self:AddLine("MSP-Style: Casual");
			elseif (current.msp_fr == "3") then
				self:AddLine("MSP-Style: Full-Time");
			elseif (current.msp_fr == "4") then
				self:AddLine("MSP-Style: Beginner");
			else
				self:AddLine("MSP-Style: "..current.msp_fr);
			end
		end
	end
	if (TipTac_Config.showMSPClient) then
		current.msp_va = GatherMSP("VA");
		if (current.msp_va ~= nil) then
			self:AddLine("MSP-Client: "..current.msp_va);
		end
	end
end);

TipTacMSPFindConfigWindowAndAddOwnConfig();